# GriddyEnv

[![Build Status](https://travis-ci.org/joemccann/dillinger.svg?branch=master)](https://travis-ci.org/joemccann/dillinger)

Simple Grid World Environment for testing and teaching RL algorithms. Integrated into OpenAI Gym.
Always looking for people to collab with and add features to the environment. Shoot me an email if you are interested! hshams@hotmail.co.uk

  - See if you can beat it!

# New Features!

  - Coming soon!

> Suggest me features!

### Tech

GriddyEnv uses a number of open source projects to work properly:

* [OpenAI Gym] - OpenAI Gym
* [Numpy] - Numerical Computation Library

### Installation

GriddyEnv requires [Python3](https://www.python.org/downloads/) to run.

Install the dependencies and devDependencies and start the server.

```sh
$ pip3 install GriddyEnv
```

### Development

Want to contribute? Great!

Contact me! hshams@hotmail.co.uk


### Todos

 - Lava tiles
 - Maze generation

License
----

MIT
**Free Software, Hell Yeah!**


   [dill]: <https://github.com/joemccann/dillinger>
   [git-repo-url]: <https://github.com/joemccann/dillinger.git>
   [john gruber]: <http://daringfireball.net>
   [df1]: <http://daringfireball.net/projects/markdown/>
   [markdown-it]: <https://github.com/markdown-it/markdown-it>
   [Ace Editor]: <http://ace.ajax.org>
   [node.js]: <http://nodejs.org>
   [Twitter Bootstrap]: <http://twitter.github.com/bootstrap/>
   [jQuery]: <http://jquery.com>
   [@tjholowaychuk]: <http://twitter.com/tjholowaychuk>
   [express]: <http://expressjs.com>
   [AngularJS]: <http://angularjs.org>
   [Gulp]: <http://gulpjs.com>

   [PlDb]: <https://github.com/joemccann/dillinger/tree/master/plugins/dropbox/README.md>
   [PlGh]: <https://github.com/joemccann/dillinger/tree/master/plugins/github/README.md>
   [PlGd]: <https://github.com/joemccann/dillinger/tree/master/plugins/googledrive/README.md>
   [PlOd]: <https://github.com/joemccann/dillinger/tree/master/plugins/onedrive/README.md>
   [PlMe]: <https://github.com/joemccann/dillinger/tree/master/plugins/medium/README.md>
   [PlGa]: <https://github.com/RahulHP/dillinger/blob/master/plugins/googleanalytics/README.md>
